==> e16_0.16.8.10.dfsg.1.orig.tar.gz: e16-0.16.8.10.dfsg.1/src/ipc.h <==
/*
 * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _IPC_H_
#define _IPC_H_

#include "etypes.h"
#include "util.h"

typedef struct
{
   void                (*func) (const char *line);
   const char         *name;
   const char         *nick;
   const char         *help_text;
   const char         *extended_help_text;
} IpcItem;

typedef struct
{
   int                 num;
   const IpcItem      *lst;
} IpcItemList;

void __PRINTF__     IpcPrintf(const char *fmt, ...);

int                 EFunc(EWin * ewin, const char *params);
void                EFuncDefer(EWin * ewin, const char *params);

#endif /* _IPC_H_ */

==> e16_0.16.8.13.orig.tar.gz: e16-0.16.8.13/src/ipc.h <==
/*
 * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _IPC_H_
#define _IPC_H_

#include "etypes.h"
#include "util.h"

typedef struct {
   void                (*func) (const char *line);
   const char         *name;
   const char         *nick;
   const char         *help_text;
   const char         *extended_help_text;
} IpcItem;

typedef struct {
   int                 num;
   const IpcItem      *lst;
} IpcItemList;

typedef void        (IpcReplyFunc) (void *data, const char *str);
int                 IpcExecReply(const char *params, IpcReplyFunc * reply,
				 void *data);
void __PRINTF__     IpcPrintf(const char *fmt, ...);

int                 EFunc(EWin * ewin, const char *params);
void                EFuncDefer(EWin * ewin, const char *params);

#endif /* _IPC_H_ */
